.. _astroML_dimensionality:

Unsupervised Learning: Dimensionality Reduction
===============================================
More information will be here soon - check for updates!

Some examples of dimensionality reduction can be found in
:ref:`book_fig_chapter7`
